/*
   This is the reference solution to problem D ('ukladanie kart')

   Author : Piotr Zielinski
*/

#include <stdio.h>
#include <stdlib.h>

#undef NDEBUG
#include <assert.h>

const int N = 1000;
const int INF = N+2;

int n;
int cards[N+1];
int minCard[N+1];

int binarySearch(int table[], int n, int key) {
  // returns the biggest i, such that table[i] <= key
  // assumes that table[0] <= key and table[n] > key
  int start = 0;
  int end = n;

  assert(table[0] <= key);
  assert(table[n] > key);

  while (start + 1 < end ) {
    // the result is in [start, end)
    int center = (start + end) / 2;
    if (table[center] <= key) 
      start = center;
    else 
      end = center;
  }
  assert(table[start] <= key);
  assert(table[start+1] > key);
  return start;
}

int linearSearch(int table[], int n, int key) {
  // returns the biggest i, such that table[i] <= key
  // assumes that table[0] <= key and table[n] > key
  assert(table[0] <= key);
  assert(table[n] > key);

  for(int i=0; i<n; i++)
    if (table[i+1] > key)
      return i;

  assert(0);
}
    

int longestIncreasingSequence() {
  // this function computes the length of the longest non-decreasing
  // subsequence in 'cards[]'.  The value in minCard[i] is the minimum
  // value of the last card that ends a subsequence of length i.
  
  minCard[1] = -1;
  for(int i=1; i<n+1; i++) // minCard[n] serves as a sentinel
    minCard[i] = INF;

  for(int i=0; i<n; i++) {
    // for each card find the longest sequence (of length 'length') such
    // that minCard[length] <= cards[i].

    // in both searches below 'n' could be replaced by 'i+1'
    int length = binarySearch(minCard, n, cards[i]);
    assert(length == linearSearch(minCard, n, cards[i]));
    assert(minCard[length] < cards[i]); // there shouldn't be any repetitions

    // we can add the card cards[i] to this sequence
    minCard[length+1] = cards[i];
  }

  for(int i=n; i>0; i--)
    if (minCard[i] < INF)
      return i;
  
  assert(0);
}
    
void loadData() {
  scanf("%i", &n);
  assert(1 <= n && n <= N);
  for(int i=0; i<n; i++) {
    scanf("%i", cards + i);
    assert(1 <= cards[i] && cards[i] <= n);
  }
}

int main(void) {
  int sets;

  scanf("%i", &sets);
  for(int i=0; i<sets; i++) {
    loadData();
    printf("%i\n", n - longestIncreasingSequence());
  }

  return 0;
}

