/*
   This is the reference solution to problem E ('transformacje')

   Author : Piotr Zielinski
*/

#include <stdio.h>
#include <string.h>

#undef NDEBUG
#include <assert.h>

const int N = 100000;
int n;

// we write two copies of T, one after the other, to avoid performing
// unnecessary modulo operations

char T[N*2];  //I use char instead of int to save space

// It can be easily shown by induction that T^(2^k)[i] = T[i] xor
// T[i+2^k].  This way, we can easily compute T(2^n).  The answer is
// 'yes' only if T(2^n) is zero.

// the steps computed by these two procedures can be different but
// they will lead to the same final answer.

int computeStep(int n) { // O(k)
  int step = 1;
  int iterations = n+2; // this could be as small as n, but I wanted
			// to be sure
  for(int i=0; i<iterations; i++)
    step = step * 2 % n;
  return step;
}

int cleverComputeStep(int n) { // O(log n)
  int step = 1;
  while (n % 2 == 0) {
    n /= 2;
    step *= 2;
  }
  return step;
}

int willBeZero(char T[], int n, int (*computeStep)(int)) {
  int step = (*computeStep)(n); 
  for(int i=0; i<n; i++)
    if (T[i] != T[i + step]) 
      return 0;
  return 1;
}

int fastWillBeZero(char T[], int n, int (*computeStep)(int)) {
  return memcmp(T, T + (*computeStep)(n), n) == 0;
}

void loadData() {
  // this is the slowest part of the program, it can probably be sped
  // up by using a less general input function than scanf
  scanf("%i", &n);
  for(int i=0; i<n; i++) {
    int temp;
    scanf("%i", &temp);
    assert(0 <= temp && temp <= 1);
    T[i + n] = T[i] = (char) temp;
  }
}

int main(void) {
  int sets;

  scanf("%i", &sets);
  for(int i=0; i<sets; i++) {
    loadData();
    int result = fastWillBeZero(T, n, cleverComputeStep);
    assert(result == fastWillBeZero(T, n, computeStep));
    assert(result == willBeZero(T, n, cleverComputeStep));
    assert(result == willBeZero(T, n, computeStep));
    printf("%s\n", result?"TAK":"NIE");
  }

  return 0;
}

  
